@@ -953,9 +953,13 @@ arv_camera_set_frame_rate (ArvCamera *camera, double frame_rate, GError **error)
 
 	switch (priv->vendor) {
 		case ARV_CAMERA_VENDOR_BASLER:
+			/* Disabling AcquisitionStart is required on some Basler cameras. Just ignore a failure. */
 			arv_camera_set_string (camera, "TriggerSelector", "AcquisitionStart", &local_error);
 			if (local_error == NULL)
 				arv_camera_set_string (camera, "TriggerMode", "Off", &local_error);
+			else
+				g_clear_error (&local_error);
+
 			if (local_error == NULL)
 				arv_camera_set_string (camera, "TriggerSelector", "FrameStart", &local_error);
 			if (local_error == NULL)
@@ -1201,7 +1205,7 @@ arv_camera_set_trigger (ArvCamera *camera, const char *source, GError **error)
 	g_return_if_fail (source != NULL);
 
 	if (priv->vendor == ARV_CAMERA_VENDOR_BASLER)
-		arv_camera_set_integer (camera, "AcquisitionFrameRateEnable", 0, &local_error);
+		arv_camera_set_boolean (camera, "AcquisitionFrameRateEnable", FALSE, &local_error);
 
 	if (local_error == NULL)
 		arv_camera_set_string (camera, "TriggerSelector", "AcquisitionStart", &local_error);
@@ -1517,6 +1521,23 @@ arv_camera_get_exposure_time_auto (ArvCamera *camera, GError **error)
 	return arv_auto_from_string (arv_camera_get_string (camera, "ExposureAuto", error));
 }
 
+/*
+ * arv_camera_set_exposure_mode:
+ * @camera: a #ArvCamera
+ * @exspoure_mode: exposure mode
+ * @error: a #GError placeholder, %NULL to ignore
+ *
+ * Defines acquisition mode.
+ *
+ * Since: 0.8.7
+ */
+
+void
+arv_camera_set_exposure_mode (ArvCamera *camera, ArvExposureMode acquisition_mode, GError **error)
+{
+	arv_camera_set_string (camera, "ExposureMode", arv_exposure_mode_to_string (acquisition_mode), error);
+}
+
 /* Analog control */
 
 /**
