@@ -86,6 +86,8 @@ typedef struct {
 	char *genicam_xml;
 	size_t genicam_xml_size;
 
+	gboolean is_big_endian_device;
+
 	gboolean is_packet_resend_supported;
 	gboolean is_write_memory_supported;
 
@@ -111,7 +113,7 @@ static gboolean
 _send_cmd_and_receive_ack (ArvGvDeviceIOData *io_data, ArvGvcpCommand command,
 			   guint64 address, size_t size, void *buffer, GError **error)
 {
-	ArvGvcpCommand ack_command;
+	ArvGvcpCommand expected_ack_command;
 	ArvGvcpPacket *ack_packet = io_data->buffer;
 	ArvGvcpPacket *packet;
 	const char *operation;
@@ -125,22 +127,22 @@ _send_cmd_and_receive_ack (ArvGvDeviceIOData *io_data, ArvGvcpCommand command,
 	switch (command) {
 		case ARV_GVCP_COMMAND_READ_MEMORY_CMD:
 			operation = "read_memory";
-			ack_command = ARV_GVCP_COMMAND_READ_MEMORY_ACK;
+			expected_ack_command = ARV_GVCP_COMMAND_READ_MEMORY_ACK;
 			ack_size = arv_gvcp_packet_get_read_memory_ack_size (size);
 			break;
 		case ARV_GVCP_COMMAND_WRITE_MEMORY_CMD:
 			operation = "write_memory";
-			ack_command = ARV_GVCP_COMMAND_WRITE_MEMORY_ACK;
+			expected_ack_command = ARV_GVCP_COMMAND_WRITE_MEMORY_ACK;
 			ack_size = arv_gvcp_packet_get_write_memory_ack_size ();
 			break;
 		case ARV_GVCP_COMMAND_READ_REGISTER_CMD:
 			operation = "read_register";
-			ack_command = ARV_GVCP_COMMAND_READ_REGISTER_ACK;
+			expected_ack_command = ARV_GVCP_COMMAND_READ_REGISTER_ACK;
 			ack_size = arv_gvcp_packet_get_read_register_ack_size ();
 			break;
 		case ARV_GVCP_COMMAND_WRITE_REGISTER_CMD:
 			operation = "write_register";
-			ack_command = ARV_GVCP_COMMAND_WRITE_REGISTER_ACK;
+			expected_ack_command = ARV_GVCP_COMMAND_WRITE_REGISTER_ACK;
 			ack_size = arv_gvcp_packet_get_write_register_ack_size ();
 			break;
 		default:
@@ -201,25 +203,26 @@ _send_cmd_and_receive_ack (ArvGvDeviceIOData *io_data, ArvGvcpCommand command,
 				success = TRUE;
 				success = success && g_poll (&io_data->poll_in_event, 1, timeout_ms) > 0;
 
-				if (success)
+				if (success) {
+					arv_gpollfd_clear_one (&io_data->poll_in_event, io_data->socket);
 					count = g_socket_receive (io_data->socket, io_data->buffer,
 								  ARV_GV_DEVICE_BUFFER_SIZE, NULL, &local_error);
-				else
+				} else
 					count = 0;
 				success = success && (count >= sizeof (ArvGvcpHeader));
 
 				if (success) {
 					ArvGvcpPacketType packet_type;
-					ArvGvcpCommand command;
+					ArvGvcpCommand ack_command;
 					guint16 packet_id;
 
 					arv_gvcp_packet_debug (ack_packet, ARV_DEBUG_LEVEL_VERBOSE_LOG);
 
 					packet_type = arv_gvcp_packet_get_packet_type (ack_packet);
-					command = arv_gvcp_packet_get_command (ack_packet);
+					ack_command = arv_gvcp_packet_get_command (ack_packet);
 					packet_id = arv_gvcp_packet_get_packet_id (ack_packet);
 
-					if (command == ARV_GVCP_COMMAND_PENDING_ACK &&
+					if (ack_command == ARV_GVCP_COMMAND_PENDING_ACK &&
 					    count >= arv_gvcp_packet_get_pending_ack_size ()) {
 						gint64 pending_ack_timeout_ms = arv_gvcp_packet_get_pending_ack_timeout (ack_packet);
 						pending_ack = TRUE;
@@ -230,7 +233,7 @@ _send_cmd_and_receive_ack (ArvGvDeviceIOData *io_data, ArvGvcpCommand command,
 						arv_log_device ("[GvDevice::%s] Pending ack timeout = %" G_GINT64_FORMAT,
 								operation, pending_ack_timeout_ms);
 					} else if (packet_type == ARV_GVCP_PACKET_TYPE_ERROR) {
-						expected_answer = command == ack_command &&
+						expected_answer = ack_command == expected_ack_command &&
 							packet_id == io_data->packet_id;
 						if (!expected_answer) {
 							arv_debug_device ("[GvDevice::%s] Unexpected answer (0x%04x)", operation,
@@ -239,7 +242,7 @@ _send_cmd_and_receive_ack (ArvGvDeviceIOData *io_data, ArvGvcpCommand command,
 							command_error = arv_gvcp_packet_get_packet_flags (ack_packet);
 					} else  {
 						expected_answer = packet_type == ARV_GVCP_PACKET_TYPE_ACK &&
-							command == ack_command &&
+							ack_command == expected_ack_command &&
 							packet_id == io_data->packet_id &&
 							count >= ack_size;
 						if (!expected_answer) {
@@ -536,8 +539,10 @@ test_packet_check (ArvDevice *device,
 
 		do {
 			n_events = g_poll (poll_fd, 1, 10);
-			if (n_events != 0)
+			if (n_events != 0) {
+				arv_gpollfd_clear_one (poll_fd, socket);
 				read_count = g_socket_receive (socket, buffer, 16384, NULL, NULL);
+			}
 			else
 				read_count = 0;
 			/* Discard late packets, read_count should be equal to packet size minus IP and UDP headers */
@@ -617,6 +622,8 @@ auto_packet_size (ArvGvDevice *gv_device, gboolean exit_early, GError **error)
 	poll_fd.events =  G_IO_IN;
 	poll_fd.revents = 0;
 
+	arv_gpollfd_prepare_all (&poll_fd, 1);
+
 	buffer = g_malloc (max_size);
 
 	success = test_packet_check (device, &poll_fd, socket, buffer, packet_size, is_command);
@@ -664,6 +671,8 @@ auto_packet_size (ArvGvDevice *gv_device, gboolean exit_early, GError **error)
 	g_clear_pointer (&buffer, g_free);
 	g_clear_object (&socket);
 
+	arv_gpollfd_finish_all (&poll_fd, 1);
+
 	arv_device_set_boolean_feature_value (device, "GevSCPSDoNotFragment", do_not_fragment, NULL);
 
 	return packet_size;
@@ -1299,6 +1308,7 @@ arv_gv_device_constructed (GObject *object)
 	GError *local_error = NULL;
 	char *address_string;
 	guint32 capabilities;
+	guint32 device_mode;
 
 	if (!G_IS_INET_ADDRESS (priv->interface_address) ||
 	    !G_IS_INET_ADDRESS (priv->device_address)) {
@@ -1341,6 +1351,8 @@ arv_gv_device_constructed (GObject *object)
 	io_data->poll_in_event.events =  G_IO_IN;
 	io_data->poll_in_event.revents = 0;
 
+	arv_gpollfd_prepare_all (&io_data->poll_in_event, 1);
+
 	priv->io_data = io_data;
 
 	arv_gv_device_load_genicam (gv_device, &local_error);
@@ -1369,12 +1381,16 @@ arv_gv_device_constructed (GObject *object)
 
 	priv->heartbeat_thread = g_thread_new ("arv_gv_heartbeat", arv_gv_device_heartbeat_thread, priv->heartbeat_data);
 
+	arv_device_read_register (ARV_DEVICE (gv_device), ARV_GVBS_DEVICE_MODE_OFFSET, &device_mode, NULL);
+	priv->is_big_endian_device = (device_mode & ARV_GVBS_DEVICE_MODE_BIG_ENDIAN) != 0;
+
 	arv_device_read_register (ARV_DEVICE (gv_device), ARV_GVBS_GVCP_CAPABILITY_OFFSET, &capabilities, NULL);
 	priv->is_packet_resend_supported = (capabilities & ARV_GVBS_GVCP_CAPABILITY_PACKET_RESEND) != 0;
 	priv->is_write_memory_supported = (capabilities & ARV_GVBS_GVCP_CAPABILITY_WRITE_MEMORY) != 0;
 
-	arv_debug_device ("[GvDevice::new] Packet resend = %s", priv->is_packet_resend_supported ? "yes" : "no");
-	arv_debug_device ("[GvDevice::new] Write memory = %s", priv->is_write_memory_supported ? "yes" : "no");
+	arv_debug_device ("[GvDevice::new] Device endianness = %s", priv->is_big_endian_device ? "big" : "little");
+	arv_debug_device ("[GvDevice::new] Packet resend     = %s", priv->is_packet_resend_supported ? "yes" : "no");
+	arv_debug_device ("[GvDevice::new] Write memory      = %s", priv->is_write_memory_supported ? "yes" : "no");
 
 	document = ARV_DOM_DOCUMENT (priv->genicam);
 	register_description = ARV_GC_REGISTER_DESCRIPTION_NODE (arv_dom_document_get_document_element (document));
@@ -1426,6 +1442,8 @@ arv_gv_device_finalize (GObject *object)
 	g_clear_pointer (&io_data->buffer, g_free);
 	g_mutex_clear (&io_data->mutex);
 
+	arv_gpollfd_finish_all (&io_data->poll_in_event, 1);
+
 	g_clear_pointer (&priv->io_data, g_free);
 
 	g_clear_object (&priv->genicam);
