@@ -117,6 +117,8 @@ arv_gv_discover_socket_list_new (void)
 		socket_list->poll_fds[i].revents = 0;
 	}
 
+	arv_gpollfd_prepare_all(socket_list->poll_fds, socket_list->n_sockets);
+
 	return socket_list;
 }
 
@@ -127,6 +129,8 @@ arv_gv_discover_socket_list_free (ArvGvDiscoverSocketList *socket_list)
 
 	g_return_if_fail (socket_list != NULL);
 
+	arv_gpollfd_finish_all (socket_list->poll_fds, socket_list->n_sockets);
+
 	for (iter = socket_list->sockets; iter != NULL; iter = iter->next) {
 		ArvGvDiscoverSocket *discover_socket = iter->data;
 
@@ -319,14 +323,26 @@ _discover (GHashTable *devices, const char *device_id)
 	arv_gv_discover_socket_list_send_discover_packet (socket_list);
 
 	do {
-		if (g_poll (socket_list->poll_fds, socket_list->n_sockets, ARV_GV_INTERFACE_DISCOVERY_TIMEOUT_MS) == 0) {
+		gint res;
+
+		res = g_poll (socket_list->poll_fds, socket_list->n_sockets, ARV_GV_INTERFACE_DISCOVERY_TIMEOUT_MS);
+		if (res <= 0) {
 			arv_gv_discover_socket_list_free (socket_list);
+
+			/* Timeout case */
+			if (res == 0)
+				return NULL;
+
+			g_critical ("g_poll returned %d (call was interrupted)", res);
+
 			return NULL;
 		}
 
 		for (i = 0, iter = socket_list->sockets; iter != NULL; i++, iter = iter->next) {
 			ArvGvDiscoverSocket *discover_socket = iter->data;
 
+			arv_gpollfd_clear_one (&socket_list->poll_fds[i], discover_socket->socket);
+
 			do {
 				g_socket_set_blocking (discover_socket->socket, FALSE);
 				count = g_socket_receive (discover_socket->socket, buffer, ARV_GV_INTERFACE_SOCKET_BUFFER_SIZE,
@@ -531,6 +547,8 @@ arv_gv_interface_camera_locate (ArvGvInterface *gv_interface, GInetAddress *devi
 		for (i = 0, iter = socket_list->sockets; iter != NULL; i++, iter = iter->next) {
 			ArvGvDiscoverSocket *socket = iter->data;
 
+			arv_gpollfd_clear_one (&socket_list->poll_fds[i], socket->socket);
+
 			do {
 				g_socket_set_blocking (socket->socket, FALSE);
 				count = g_socket_receive (socket->socket, buffer,
@@ -662,8 +680,8 @@ arv_gv_interface_open_device (ArvInterface *interface, const char *device_id, GE
 	return NULL;
 }
 
-static ArvInterface *gv_interface = NULL;
-static GMutex gv_interface_mutex;
+static ArvInterface *arv_gv_interface = NULL;
+static GMutex arv_gv_interface_mutex;
 
 /**
  * arv_gv_interface_get_instance:
@@ -676,27 +694,27 @@ static GMutex gv_interface_mutex;
 ArvInterface *
 arv_gv_interface_get_instance (void)
 {
-	g_mutex_lock (&gv_interface_mutex);
+	g_mutex_lock (&arv_gv_interface_mutex);
 
-	if (gv_interface == NULL)
-		gv_interface = g_object_new (ARV_TYPE_GV_INTERFACE, NULL);
+	if (arv_gv_interface == NULL)
+		arv_gv_interface = g_object_new (ARV_TYPE_GV_INTERFACE, NULL);
 
-	g_mutex_unlock (&gv_interface_mutex);
+	g_mutex_unlock (&arv_gv_interface_mutex);
 
-	return ARV_INTERFACE (gv_interface);
+	return ARV_INTERFACE (arv_gv_interface);
 }
 
 void
 arv_gv_interface_destroy_instance (void)
 {
-	g_mutex_lock (&gv_interface_mutex);
+	g_mutex_lock (&arv_gv_interface_mutex);
 
-	if (gv_interface != NULL) {
-		g_object_unref (gv_interface);
-		gv_interface = NULL;
+	if (arv_gv_interface != NULL) {
+		g_object_unref (arv_gv_interface);
+		arv_gv_interface = NULL;
 	}
 
-	g_mutex_unlock (&gv_interface_mutex);
+	g_mutex_unlock (&arv_gv_interface_mutex);
 }
 
 static void
